"A 'include_strip' templatetag for django to strip trailing and leading spaces/newlines"
VERSION = (0, 1, 0)

__author__ = 'Stephane "Twidi" Angel'
__contact__ = "s.angel@twidid.com"
__homepage__ = "https://github.com/twidi/django-include-strip-tag"
__version__ = ".".join(map(str, VERSION))

